==> intelliw-1.1.0.tar.gz: intelliw-1.1.0/intelliw/interface/apijob.py <==
#!/usr/bin/env python
# coding: utf-8

import os
import json
import signal
import tornado
import tornado.ioloop
import tornado.web
import tornado.httpserver
import intelliw.utils.message as message
from intelliw.core.config import config
from intelliw.utils.util import default_dump
from intelliw.tools.infer import Infer
from intelliw.tools.report import RestReport
from intelliw.utils.logger import get_logger
from intelliw.tools.global_val import gl
from intelliw.interface import apihandler

logger = get_logger()

childs = []


def exit_handler(signum, frame):
    for child in childs:
        child.terminate()


class Application(tornado.web.Application):
    def __init__(self, custom_router, reporter):
        # Set settings
        settings = dict(
            static_path=os.path.join(os.path.dirname(__file__), "static"),
            template_path=os.path.join(os.path.dirname(__file__), "templates"),
            xsrf_cookies=False,
            autoescape=None,
            session_age=10 * 60 * 60,
        )

        # Set URL handlers
        handlers = [(r'/healthcheck', apihandler.HealthCheckHandler)]
        # 加载自定义api, 配置在algorithm.yaml中
        for r in custom_router:
            path, func = r["path"], r["func"]
            handlers.append((path, apihandler.MainHandler, {'func': func}))
            logger.info(f"方法: {func} 加载成功， 访问路径：{path}， 访问方法:POST")
        if len(custom_router) == 0:
            handlers.append((r'/predict', apihandler.MainHandler, {'func': 'infer'})) # 默认值

        self.reporter = reporter
        tornado.web.Application.__init__(self, handlers, **settings)


class ApiService:
    def __init__(self, port, path, response_addr):
        self.port = port        # 8888
        self.PERODIC_INTERVAL = config.PERODIC_INTERVAL if config.PERODIC_INTERVAL == 0 else 10
        infer = Infer(path, response_addr, self.PERODIC_INTERVAL)

        # 获取自定义api
        self.custom_router = infer.pipeline.custom_router

        # infer存入全局
        gl.set("infer", infer)

        self.reporter = RestReport(response_addr)
        msg = [{
            'status': 'start',  # 'start'
            'inferid': config.INFER_ID,             # ''
            'instanceid': config.INSTANCE_ID,       # ''
            'inferTaskStatus': []           # []
        }]
        self.reporter.report(
            message.CommonResponse(200, "inferstatus", '', json.dumps(msg, default=default_dump, ensure_ascii=False)))

    def perodic_callback(self):
        gl.get("infer").perodic_callback()
        if self.PERODIC_INTERVAL > 0:
            self.io_loop.call_later(
                self.PERODIC_INTERVAL, self.perodic_callback)

    def run(self):
        signal.signal(signal.SIGILL, exit_handler)
        app = tornado.httpserver.HTTPServer(
            request_callback=Application(self.custom_router, self.reporter), xheaders=True)
        app.listen(self.port)
        self.io_loop = tornado.ioloop.IOLoop.instance()
        if self.PERODIC_INTERVAL > 0:
            self.io_loop.call_later(
                self.PERODIC_INTERVAL, self.perodic_callback)
        self.io_loop.start()

==> intelliw-1.1.9.tar.gz: intelliw-1.1.9/intelliw/interface/apijob.py <==
#!/usr/bin/env python
# coding: utf-8

import os
import json
import signal
import tornado
import intelliw.utils.message as message
from intelliw.config import config
from intelliw.utils.util import default_dump
from intelliw.core.infer import Infer
from intelliw.core.report import RestReport
from intelliw.utils.logger import get_logger
from intelliw.utils.global_val import gl
from intelliw.interface import apihandler

logger = get_logger()

childs = []


def exit_handler(signum, frame):
    for child in childs:
        child.terminate()


class Application(tornado.web.Application):
    def __init__(self, custom_router, reporter):
        # Set settings
        settings = dict(
            static_path=os.path.join(os.path.dirname(__file__), "static"),
            template_path=os.path.join(os.path.dirname(__file__), "templates"),
            xsrf_cookies=False,
            autoescape=None,
            session_age=10 * 60 * 60,
        )

        # Set URL handlers
        handlers = [(r'/healthcheck', apihandler.HealthCheckHandler)]
        # 加载自定义api, 配置在algorithm.yaml中
        has_infer = False
        for r in custom_router:
            path, func = r["path"], r["func"]
            if func == 'infer':
                has_infer = True
            handlers.append((path, apihandler.MainHandler, {'func': func}))
            logger.info(f"方法: {func} 加载成功， 访问路径：{path}， 访问方法:POST")
                
        if len(custom_router) == 0 or not has_infer:
            handlers.append((r'/predict', apihandler.MainHandler, {'func': 'infer'})) # 默认值
            logger.info(f"方法: infer 加载成功， 访问路径：/predict， 访问方法:POST")

        self.reporter = reporter
        tornado.web.Application.__init__(self, handlers, **settings)


class ApiService:
    def __init__(self, port, path, response_addr):
        self.port = port        # 8888
        self.PERODIC_INTERVAL = config.PERODIC_INTERVAL if config.PERODIC_INTERVAL == 0 else 10
        infer = Infer(path, response_addr, self.PERODIC_INTERVAL)

        # 获取自定义api
        self.custom_router = infer.pipeline.custom_router

        # infer存入全局
        gl.set("infer", infer)

        self.reporter = RestReport(response_addr)
        msg = [{
            'status': 'start',  # 'start'
            'inferid': config.INFER_ID,             # ''
            'instanceid': config.INSTANCE_ID,       # ''
            'inferTaskStatus': []           # []
        }]
        self.reporter.report(
            message.CommonResponse(200, "inferstatus", '', json.dumps(msg, default=default_dump, ensure_ascii=False)))

    def perodic_callback(self):
        gl.get("infer").perodic_callback()
        if self.PERODIC_INTERVAL > 0:
            self.io_loop.call_later(
                self.PERODIC_INTERVAL, self.perodic_callback)

    def run(self):
        signal.signal(signal.SIGILL, exit_handler)
        app = tornado.httpserver.HTTPServer(
            request_callback=Application(self.custom_router, self.reporter), xheaders=True)
        app.listen(self.port)
        self.io_loop = tornado.ioloop.IOLoop.instance()
        if self.PERODIC_INTERVAL > 0:
            self.io_loop.call_later(
                self.PERODIC_INTERVAL, self.perodic_callback)
        self.io_loop.start()
